@@ -2,17 +2,18 @@
 # These tools are specifically to aid instructors in setting
 # up notebook templates with embedded instructions and tools
 # for students.
-# J. Gutow <jgutow@new.rr.com> January 2021
+# J. Gutow <jgutow@new.rr.com>
 # license GPL V3 or greater.
 
-from IPython.display import HTML
+from IPython.display import display, HTML
 from IPython.display import Javascript as JS
 
 import os
-# Instructor tools menu
 from input_table import * #import the input table builder
 import JPSLUtils # import the Utilities
-# Locate JupyterPiDAQ package directory
+import JPSLMenus # import tools for hierarchical menus
+
+# Locate jupyter-instructortools package directory
 mydir = os.path.dirname(__file__)  # absolute path to directory containing this file.
 
 def instmenu_act():
@@ -25,7 +26,7 @@ def instmenu_act():
     tempscript += tempJSfile.read() + '</script>'
     tempJSfile.close()
     display(HTML(tempscript))
-    JPSLUtils.OTJS('createInstructorToolsMenu()')
+    display(JS('InstructorTools.createInstructorToolsMenu()'))
     warnstr = "This cell should only contain `import InstructorTools`"
     warnstr += " as it will be deleted when the tools"
     warnstr+= " are deactivated.\n\nWARNING: if you select the '!deactivate "
@@ -40,11 +41,6 @@ def instmenu_deact():
     Removes the instructor menu from the Jupyter menu bar
     :return:
     """
-#    tempJSfile = open(os.path.join(mydir, 'javascript', 'InstructorToolsmnu.js'))
-#    tempscript = '<script type="text/javascript">'
-#    tempscript += tempJSfile.read() + '</script>'
-#    tempJSfile.close()
-#    display(HTML(tempscript))
     display(JS('deleteInstructorToolsMenu()'))
     print("Delete this cell after the menu has been removed.")
     pass
